#!/bin/bash

# ./files.sh [-l location] [--location location] [-e extension] [--extension extension] [-s] [--stats] [-h] [--help]

usage () {
   echo "USAGE: $0 ./files.sh [-l location] [--location location] [-e extension] [--extension extension] [-s] [--stats] [-h] [--help]"
   echo "Examples:"
   echo "$0 -l /etc/  -e txt  -s"
   echo "$0 -e img  --stats"
   echo
   exit 1
}

LOC_SET=0		# 0 - location is not set, use current location		1 - location set
STATS=0			# 0 - do not display statistics				1 - display statistics

while [ $# -gt 0 ]
do
   case $1 in
      -l|--location )
         LOCATION="$2"
         if ! [ -d "$LOCATION" ]; then
            usage
         fi
         LOC_SET=1
         shift
         shift
         ;;
      -e|--extension )
         EXT="$2"
         shift
         shift
         ;;
      -s|--stats )
         STATS=1
         shift
         ;;
      -h|--help )
         shift
         usage
         ;;
       * )
         usage
   esac

done

if [ $LOC_SET -ne "1" ]; then
   LOCATION=$(pwd)
fi

echo "Location: $LOCATION"

if [ "$EXT" != "" ]; then
   ls -l $LOCATION | awk '/^-/' | grep "\.$EXT$" &> /dev/null
   if [ $? -ne 0 ]; then
      echo "No file with extension $EXT was found"
      exit 2
   fi

   # count the size of files with specific extension
   ls -l $LOCATION | awk '/^-/' | grep "\.$EXT" | awk -v stats=$STATS -f /home/elbartochel/udemyscripts/awk/size.awk


else
   ls -l $LOCATION | awk '/^-/' | awk -v stats=$STATS -f /home/elbartochel/udemyscripts/awk/size.awk

fi
